from pydantic import BaseModel

from zen_dash.page import Page
class Zen:

    @staticmethod
    def full_url() -> str:
        raise Exception("Not Implimented")

    @staticmethod
    def url() -> str:
        raise Exception("Not Implimented")
    
    @staticmethod
    def view():
        raise Exception("Not Implimented")

    @staticmethod
    def server_full_url() -> str:
        raise Exception("Not Implimented")
    
    @staticmethod
    def server_url() -> str:
        raise Exception("Not Implimented")
    
    @staticmethod
    def server_view():
        raise Exception("Not Implimented")

    @staticmethod
    def server():
        raise Exception("Not Implimented")

    
class ZenPage(BaseModel):
    name: str
    icon: str
    page: Page





from typing import Optional
from zen_dash.support import BaseUpdate


class FlexData(BaseUpdate):
    fxFlex: Optional[str] = "18%" 
    fxFlex_md: Optional[str] = "33%"
    fxFlex_sm: Optional[str] = "50%" 
    fxFlex_xs: Optional[str] = "100%" 
    class Config:
        exclude_none=True